@@ -596,7 +596,7 @@ void UMultCTM(Matrix *ctm, XPoint position, float scale, short rotate)
    tmpb = yscale * sin(drot);
    tmpd = -scale * sin(drot);
    tmpe = yscale * cos(drot);
-   
+
    mata = ctm->a * tmpa + ctm->d * tmpb;
    matb = ctm->b * tmpa + ctm->e * tmpb;
    matc = ctm->c * tmpa + ctm->f * tmpb + position.x;
@@ -723,14 +723,15 @@ void UPreMultCTMbyMat(Matrix *ctm, Matrix *pre)
 void UTransformbyCTM(Matrix *ctm, XPoint *ipoints, XPoint *points, short number)
 {
    pointlist current, ptptr = points;
+   float fx, fy;
    short tmpx;
 
    for (current = ipoints; current < ipoints + number; current++, ptptr++) {
-      tmpx = (short)(ctm->a * (float)current->x + ctm->b * (float)current->y
-		 + ctm->c);
-      ptptr->y = (short)(ctm->d * (float)current->x + ctm->e * (float)current->y
-		 + ctm->f);
-      ptptr->x = tmpx;
+      fx = ctm->a * (float)current->x + ctm->b * (float)current->y + ctm->c;
+      fy = ctm->d * (float)current->x + ctm->e * (float)current->y + ctm->f;
+	
+      ptptr->x = (fx >= 0) ? (short)(fx + 0.5) : (short)(fx - 0.5);
+      ptptr->y = (fy >= 0) ? (short)(fy + 0.5) : (short)(fy - 0.5);
    }
 }
   
@@ -743,10 +744,13 @@ void UfTransformbyCTM(Matrix *ctm, XfPoint *fpoints, XPoint *points, short numbe
 {
    fpointlist current;
    pointlist new = points;
+   float fx, fy;
 
    for (current = fpoints; current < fpoints + number; current++, new++) {
-      new->x = (short)(ctm->a * current->x + ctm->b * current->y + ctm->c);
-      new->y = (short)(ctm->d * current->x + ctm->e * current->y + ctm->f);
+      fx = ctm->a * current->x + ctm->b * current->y + ctm->c;
+      fy = ctm->d * current->x + ctm->e * current->y + ctm->f;
+      new->x = (fx >= 0) ? (short)(fx + 0.5) : (short)(fx - 0.5);
+      new->y = (fy >= 0) ? (short)(fy + 0.5) : (short)(fy - 0.5);
    }
 }
 
@@ -1831,11 +1835,11 @@ void strokepath(XPoint *pathlist, short number, short style, float width)
       if (style & (DASHED | DOTTED)) {
          SetDashes(dpy, areastruct.gc, 0, dashstring, 2);
          SetLineAttributes(dpy, areastruct.gc, tmpwidth, LineOnOffDash,
-		CapButt, JoinBevel);
+		CapButt, JoinMiter);
       }
       else
          SetLineAttributes(dpy, areastruct.gc, tmpwidth, LineSolid,
-		CapRound, JoinBevel);
+		(style & SQUARECAP) ? CapProjecting : CapRound, JoinMiter);
 
       /* draw the spline and close off if so specified */
       DrawLines(dpy, areastruct.areawin, areastruct.gc, pathlist,
@@ -1953,7 +1957,7 @@ void UDrawObject(objinstptr theinstance, short level, int passcolor, pushlistptr
    int		defaultcolor = passcolor;
    int		curcolor = passcolor;
    int		thispart;
-   XPoint 	bboxin, bboxout[2];
+   XPoint 	bboxin[2], bboxout[2];
    u_char	xm, ym;
    objectptr	theobject = theinstance->thisobject;
 
@@ -1970,10 +1974,13 @@ void UDrawObject(objinstptr theinstance, short level, int passcolor, pushlistptr
 
    /* do a quick test for intersection with the display window */
 
-   UTransformbyCTM(DCTM, &(theobject->bbox.lowerleft), &(bboxout[0]), 1);
-   bboxin.x = theobject->bbox.lowerleft.x + theobject->bbox.width;
-   bboxin.y = theobject->bbox.lowerleft.y + theobject->bbox.height; 
-   UTransformbyCTM(DCTM, &bboxin, &(bboxout[1]), 1);
+   bboxin[0].x = theobject->bbox.lowerleft.x;
+   bboxin[0].y = theobject->bbox.lowerleft.y;
+   bboxin[1].x = theobject->bbox.lowerleft.x + theobject->bbox.width;
+   bboxin[1].y = theobject->bbox.lowerleft.y + theobject->bbox.height; 
+   if (level == 0)
+      extendschembbox(theinstance, &(bboxin[0]), &(bboxin[1]));
+   UTransformbyCTM(DCTM, &bboxin, &bboxout, 2);
 
    xm = (bboxout[0].x < bboxout[1].x) ? 0 : 1;  
    ym = (bboxout[0].y < bboxout[1].y) ? 0 : 1;  
@@ -2179,8 +2186,12 @@ void TopDoLatex()
    fprintf(f, "\\def\\topbox#1{\\raisebox{-\\baselineskip}[0in][0in]{#1}}\n");
    fprintf(f, "\\def\\midbox#1{\\raisebox{-0.5\\baselineskip}[0in][0in]{#1}}\n");
    fprintf(f, "\\begin{flushleft}\n");
-   fprintf(f, "\\epsfig{file=%s.ps}\\\\\n",
-		xobjs.pagelist[areastruct.page]->filename);
+
+   filename[strlen(filename) - 4] = '\0';
+   if (strchr(filename, '.') == NULL)
+      sprintf(filename + strlen(filename), ".ps");
+
+   fprintf(f, "\\epsfig{file=%s}\\\\\n", filename);
 
    psscale = getpsscale(xobjs.pagelist[areastruct.page]->outscale,
 		areastruct.page);
