@@ -275,8 +275,8 @@ graphicptr new_graphic(objinstptr destinst, char *filename, int px, int py)
     int nf, nr, width, height, imax, x, y, i;
     char id[5], c, buf[128];
     union {
-       unsigned char b[4];
-       unsigned long i;
+       u_char b[4];
+       u_long i;
     } pixel;
 
     locdestinst = (destinst == NULL) ? areastruct.topinstance : destinst;
