@@ -507,7 +507,7 @@ int add_vbinding(int keywstate, int function, short value)
 
 int add_binding(int keywstate, int function)
 {
-   return add_vbinding(keywstate, function, -1);
+   return add_vbinding(keywstate, function, (short)-1);
 }
 
 /*--------------------------------------------------------------*/
@@ -708,10 +708,15 @@ void default_keybindings()
    }
    else {
       add_binding(BUTTON2, XCF_Text_Return);
+      add_binding(SHIFT | BUTTON1, XCF_Text_Return);
       add_binding(BUTTON2, XCF_Select);
+      add_binding(SHIFT | BUTTON1, XCF_Select);
       add_binding(HOLD | BUTTON2, XCF_SelectBox);
+      add_binding(SHIFT | HOLD | BUTTON1, XCF_Select);
       add_binding(BUTTON2, XCF_Finish_Element);
+      add_binding(SHIFT | BUTTON1, XCF_Finish_Element);
       add_binding(BUTTON2, XCF_Finish_Copy);
+      add_binding(SHIFT | BUTTON1, XCF_Finish_Copy);
       add_binding(BUTTON3, XCF_Cancel_Last);
       add_binding(BUTTON3, XCF_Cancel);
    }
@@ -731,7 +736,7 @@ static int button1mode = XCF_Wire;
 void mode_rebinding(int newmode, int newvalue)
 {
    remove_binding(BUTTON1, button1mode);
-   add_vbinding(BUTTON1, newmode, newvalue);
+   add_vbinding(BUTTON1, newmode, (short)newvalue);
    button1mode = newmode;
    toolcursor(newmode);
 }
@@ -743,12 +748,12 @@ void mode_rebinding(int newmode, int newvalue)
 
 void mode_tempbinding(int newmode, int newvalue)
 {
-   int saveval;
+   short saveval;
    XPoint cpos;
 
    if (isnbound(BUTTON1, button1mode, &saveval)) {
       remove_binding(BUTTON1, button1mode);
-      add_vbinding(BUTTON1, newmode, newvalue);
+      add_vbinding(BUTTON1, newmode, (short)newvalue);
       cpos = UGetCursor();
       eventdispatch(BUTTON1, (int)cpos.x, (int)cpos.y);
       remove_binding(BUTTON1, newmode);
