@@ -230,6 +230,16 @@ int get_num_params(objectptr thisobj)
    return nparam;
 }
 
+/*----------------------------------------------------------------------*/
+/* Remove all element parameters from an element			*/
+/*----------------------------------------------------------------------*/
+
+void free_all_eparams(genericptr thiselem)
+{
+   while (thiselem->passed != NULL)
+      free_element_param(thiselem, thiselem->passed);
+}
+
 /*----------------------------------------------------------------------*/
 /* Remove an element parameter (eparam) and free memory associated with	*/
 /* the parameter key.							*/
@@ -2085,6 +2095,7 @@ void removeparams(objectptr thisobj)
 	 free(ops->parameter.expr);
       free(ops);
    }
+   thisobj->params = NULL;
 }
 
 /*-----------------------------------------------------------------------*/
