@@ -408,6 +408,7 @@ enum loadmodes {IMPORT = 1, PSBKGROUND, SCRIPT, RECOVER,
 #define FILLSOLID 224  /* = 32 + 64 + 128 */
 #define OPAQUE 256
 #define BBOX 512
+#define SQUARECAP 1024
 
 /*----------------------------------------------------------------------*/
 /* Box edit styles							*/
@@ -1354,6 +1355,7 @@ typedef struct {
 typedef struct {
    char		*tempfile;
    char		*tempdir;
+   Boolean	retain_backup;
    xcIntervalId	timeout_id;
    int		save_interval;
    short	do_replace;
